PySAL: Python Spatial Analysis Library — pysal v25.7rc1 Manual

Skip to main content
`Ctrl`+`K`

# PySAL: Python Spatial Analysis Library

PySAL is an open source cross-platform library for geospatial data science with an emphasis on geospatial vector data written in Python.

###### Housing Prices Berlin

###### Rose diagram (directional LISAs)

###### Visualizing Non Planar Neighbours

PySAL supports the development of high level applications for spatial analysis, such as

- detection of spatial clusters, hot-spots, and outliers

- construction of graphs from spatial data

- spatial regression and statistical modeling on geographically embedded networks

- spatial econometrics

- exploratory spatio-temporal data analysis

# PySAL Components

- explore - modules to conduct exploratory analysis of spatial and spatio-temporal data, including statistical testing on points, networks, and polygonal lattices. Also includes methods for spatial inequality, distributional dynamics, and segregation.

- viz - visualize patterns in spatial data to detect clusters, outliers, and hot-spots.

- model - model spatial relationships in data with a variety of linear, generalized-linear, generalized-additive, and nonlinear models.

- lib - solve a wide variety of computational geometry problems:

  - graph construction from polygonal lattices, lines, and points.

  - construction and interactive editing of spatial weights matrices & graphs

  - computation of alpha shapes, spatial indices, and spatial-topological relationships

  - reading and writing of sparse graph data, as well as pure python readers of spatial vector data.

Details are available in the PySAL api.

For background information see [AR14, CRKW19, FBG+22, Fle19, FYK17, GRL21, LABC+20, RHK+20, Rey14, Rey19, RA07, RAA+22, RCK21, RArribasBelW23, SKA+21, WKR19, YFL+19].

## Development

As of version 2.0.0, PySAL is now a collection of affiliated geographic data science packages. Changes to the code for any of the subpackages should be directed at the respective upstream repositories and not made here. Infrastructural changes for the meta-package, like those for tooling, building the package, and code standards, will be considered.

PySAL development is hosted on github.

Discussions of development occurs on the developer list as well as discord.

## Getting Involved

If you are interested in contributing to PySAL please see our development guidelines.

## Bug reports

To search for or report bugs, please see PySAL’s issues.

## Citing PySAL

If you use PySAL in a scientific publication, we would appreciate citations to the following paper:

> PySAL: A Python Library of Spatial Analytical Methods, Rey, S.J. and L. Anselin, Review of Regional Studies 37, 5-27 2007.

> Bibtex entry:

>     @Article{pysal2007,
>       author={Rey, Sergio J. and Anselin, Luc},
>       title={{PySAL: A Python Library of Spatial Analytical Methods}},
>       journal={The Review of Regional Studies},
>       year=2007,
>       volume={37},
>       number={1},
>       pages={5-27},
>       keywords={Open Source; Software; Spatial}
>     }

## License information

See the file “LICENSE.txt” for information on the history of this software, terms & conditions for usage, and a DISCLAIMER OF ALL WARRANTIES.